@@ -59,7 +59,7 @@ def setup_aio(node_ip,account_name,user_name,password,email,license):
             logger.error(f'Unhandled exception: {e}')
             return(e)
         try:
-            token = _get_morpheus_api_token(node_ip,user_name,password)
+            token = get_morpheus_api_token(node_ip,user_name,password)
         except Exception as e:
             logger.error(f'Unhandled exception: {e}')
             return(e)
@@ -132,15 +132,15 @@ def _get_appliance_node_status(node_ip):
         out = resp
     return(out)
 
-def _get_morpheus_api_token(url,user_name,password):
+def get_morpheus_api_token(url,user_name,password):
     """
-    The _get_morpheus_api_token function is used to get a Morpheus API token.
+    The get_morpheus_api_token function is used to get a Morpheus API token.
     It takes three arguments: the URL of the Morpheus appliance, a username and password.
     The function returns an access_token which can be used in subsequent requests.
     
     :param url: Specify the morpheus api instance that is being used
     :param user_name: Specify the username of the user that is used to authenticate with the morpheus api
-    :param password: Pass the password to _get_morpheus_api_token function
+    :param password: Pass the password to get_morpheus_api_token function
     :return: A token for the user
     :doc-author: Trelent
     """
@@ -374,4 +374,7 @@ def get_lab_instance_ids_from_tag(url,headers,controller_id,tag_name):
     for tag in tags:
         if tag["name"] == tag_name:
             ids = tag["value"]
-    return(json.loads(ids))
\ No newline at end of file
+    return(json.loads(ids))
+
+
+
